( cd usr/lib ; rm -rf libpixregion.so.1 )
( cd usr/lib ; ln -sf libpixregion.so.1.0.0 libpixregion.so.1 )
( cd usr/lib ; rm -rf libpixregion.so )
( cd usr/lib ; ln -sf libpixregion.so.1.0.0 libpixregion.so )
